@@ -74,25 +74,25 @@ class NetworkMetrics(blockdiag.metrics.NodeMetrics):
     @property
     def top(self):
         pt = self.box.top
-        return XY(pt.x, pt.y - self.metrics.span_height / 2)
+        return XY(pt.x, pt.y - self.span_height / 2)
 
     @property
     def left(self):
         pt = self.box.left
-        return XY(pt.x - self.metrics.span_width / 2, pt.y)
+        return XY(pt.x - self.span_width / 2, pt.y)
 
     @property
     def right(self):
         pt = self.box.right
-        return XY(pt.x + self.metrics.span_width / 2, pt.y)
+        return XY(pt.x + self.span_width / 2, pt.y)
 
     @property
     def textbox(self):
         x = self.left.x
         y = self.top.y
 
-        width = self.metrics.node_width * 3 / 2
-        height = self.metrics.node_height
+        width = self.node_width * 3 / 2
+        height = self.node_height
 
         return Box(x - width, y - height / 2, x, y + height / 2)
 
@@ -104,8 +104,6 @@ class NodeMetrics(blockdiag.metrics.NodeMetrics):
 
     @property
     def connectors(self):
-        m = self.metrics
-
         above = [n for n in self.node.networks if n.xy.y <= self.node.xy.y]
         above.sort(lambda a, b: -cmp(a.xy.y, b.xy.y))
 
@@ -120,26 +118,26 @@ class NodeMetrics(blockdiag.metrics.NodeMetrics):
                 if network.hidden:
                     span = 0
                 else:
-                    span = m.trunk_diameter / 2
+                    span = self.trunk_diameter / 2
 
                 if network.xy.y <= self.node.xy.y:
                     x, y2 = self.top
-                    y1 = m.network(network).top.y + span
+                    y1 = self.network(network).top.y + span
                 else:
                     x, y1 = self.bottom
-                    y2 = m.network(network).top.y - span
+                    y2 = self.network(network).top.y - span
 
                 if len(networks) == 1:
                     dx = 0
                 else:
                     pos = networks.index(network)
                     base_x = (len(networks) - 1) / 2.0 - pos
-                    dx = int(math.floor(base_x * m.cellsize * 2))
+                    dx = int(math.floor(base_x * self.cellsize * 2))
 
-                width = m.node_width + m.span_width
-                textbox = Box(x + dx + m.cellsize / 2,
-                              y2 - m.span_height / 2,
-                              x + width - m.cellsize / 2,
+                width = self.node_width + self.span_width
+                textbox = Box(x + dx + self.cellsize / 2,
+                              y2 - self.span_height / 2,
+                              x + width - self.cellsize / 2,
                               y2)
                 line = [XY(x + dx, y1), XY(x + dx, y2)]
 
@@ -164,11 +162,11 @@ class GroupMetrics(blockdiag.metrics.NodeMetrics):
     @property
     def grouplabelbox(self):
         box = super(GroupMetrics, self).grouplabelbox
-        span = self.metrics.cellsize
+        span = self.cellsize
         box = Box(box[0], box[1] + span, box[2], box[3] + span)
 
         if self.is_root_group:
-            width = (self.metrics.node_width + self.metrics.span_width) / 2
+            width = (self.node_width + self.span_width) / 2
             box = Box(box[0] + width, box[1], box[2] + width, box[3])
 
         return box
@@ -176,7 +174,7 @@ class GroupMetrics(blockdiag.metrics.NodeMetrics):
     @property
     def marginbox(self):
         box = super(GroupMetrics, self).box
-        margin_x = self.metrics.span_height / 2 - self.metrics.cellsize
-        margin_y = self.metrics.cellsize
+        margin_x = self.span_height / 2 - self.cellsize
+        margin_y = self.cellsize
         return Box(box[0] - margin_y, box[1] - margin_x,
                    box[2] + margin_y, box[3] + margin_x)
