@@ -19,6 +19,7 @@ from docutils.parsers import rst
 from nwdiag import parser
 from nwdiag.builder import ScreenNodeBuilder
 from nwdiag.drawer import DiagramDraw
+from nwdiag.utils.rst.nodes import nwdiag
 from blockdiag.utils.rst import directives
 
 
@@ -33,10 +34,6 @@ directive_options_default = dict(format='PNG',
 directive_options = {}
 
 
-class nwdiag(nodes.General, nodes.Element):
-    pass
-
-
 class NwdiagDirectiveBase(directives.BlockdiagDirectiveBase):
     """ Directive to insert arbitrary dot markup. """
     name = "nwdiag"
