@@ -13,6 +13,20 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+import nwdiag.parser
+import nwdiag.builder
+import nwdiag.drawer
+core = nwdiag
+
+import blockdiag.utils.bootstrap
+import blockdiag.utils.collections
+import blockdiag.utils.fontmap
+utils = blockdiag.utils
+
+from nwdiag.utils.rst import nodes
+from nwdiag.utils.rst import directives
+
+# FIXME: obsoleted interface (keep for compatibility)
 from blockdiag.utils import collections
 from blockdiag.utils.fontmap import FontMap
 from nwdiag import command, parser, builder, drawer
