@@ -13,6 +13,20 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+import packetdiag.parser
+import packetdiag.builder
+import packetdiag.drawer
+core = packetdiag
+
+import blockdiag.utils.bootstrap
+import blockdiag.utils.collections
+import blockdiag.utils.fontmap
+utils = blockdiag.utils
+
+from packetdiag.utils.rst import nodes
+from packetdiag.utils.rst import directives
+
+# FIXME: obsoleted interface (keep for compatibility)
 from blockdiag.utils import collections
 from blockdiag.utils.fontmap import FontMap
 from packetdiag import command, parser, builder, drawer
