@@ -19,10 +19,6 @@ import rackdiag.drawer
 import rackdiag.parser
 from blockdiag.utils.bootstrap import Application
 
-# for compatibility
-from blockdiag.utils.bootstrap import create_fontmap, detectfont
-(create_fontmap, detectfont)
-
 
 class RackdiagApp(Application):
     module = rackdiag
